@@ -14,8 +14,8 @@ try:
     aesDecrypt = aesEncrypt
 
 except ImportError:
-    from Crypto.Cipher import AES
-    from Crypto.Util import Counter
+    from Cryptodome.Cipher import AES
+    from Cryptodome.Util import Counter
 
     def aesEncrypt(data, key):
         cipher = AES.new(key, AES.MODE_CTR,
@@ -28,7 +28,7 @@ except ImportError:
                          counter=Counter.new(128, initial_value=0))
         return cipher.decrypt(data)
 
-
+has_aes = True
 
 def getKeyLength():
     return 32
